@@ -38,4 +38,8 @@ class Random():
         return Position(
             self.random_number(self.screen.left, self.screen.right),
             self.random_number(self.screen.bottom, self.screen.top)
-        )
\ No newline at end of file
+        )
+ 
+    def random_item(self, items):
+        assert len(items) > 0
+        return items[self.random_number(0, len(items)-1)]
\ No newline at end of file
